

models.Property
===============

.. autoclass:: pykechain.models.Property
   :members:

pykechain Property Types
------------------------

.. autoclass:: pykechain.models.AttachmentProperty
   :members:

.. autoclass:: pykechain.models.MultiReferenceProperty
   :members:

.. autoclass:: pykechain.models.SelectListProperty
   :members:

.. autoclass:: pykechain.models.DatetimeProperty
   :members:
